@@ -45,6 +45,7 @@ class ChatConfig:
             "show_tokens": True,
             "show_metadata": True,
             "readline_enabled": True,
+            "claude_commands_enabled": True,
         },
         "paths": {
             "log_location": "~/.chat_loop_logs",
@@ -54,10 +55,6 @@ class ChatConfig:
             "retry_delay": 2.0,
             "timeout": 120.0,
             "spinner_style": "dots",
-            # Suppress agent library stdout during streaming using smart filter
-            # Smart filter allows interactive tool prompts (Y/n) to pass through
-            # while suppressing accumulated agent output
-            "suppress_agent_stdout": True,
         },
         "ui": {
             "show_banner": True,
@@ -70,12 +67,6 @@ class ChatConfig:
             "enabled": True,
             "notification_sound": None,  # Uses bundled notification.wav if None
         },
-        "harmony": {
-            # Enable harmony processing (auto-detects by default, set to True to force)
-            "enabled": None,  # None = auto-detect, True = force enable, False = disable
-            # Show reasoning/analysis/commentary channels
-            "show_detailed_thinking": True,
-        },
         "context": {
             # Warning thresholds for context usage (as percentages)
             # Show warnings when token usage exceeds these thresholds
@@ -379,10 +370,6 @@ behavior:
   retry_delay: 2.0             # Seconds to wait between retries
   timeout: 120.0               # Request timeout in seconds
   spinner_style: dots          # Thinking indicator style (dots, line, arc, etc.)
-  suppress_agent_stdout: true  # Suppress agent library stdout during streaming
-                               # Uses smart filter to allow interactive prompts
-                               # (Y/n confirmations) through while suppressing
-                               # other output
 
 # ============================================================================
 # UI - User interface preferences
@@ -400,21 +387,6 @@ audio:
   enabled: true                # Play sound when agent completes a turn
   notification_sound: null     # Path to custom WAV file (uses bundled sound if null)
 
-# ============================================================================
-# HARMONY - OpenAI Harmony format settings (for gpt-oss models)
-# ============================================================================
-# IMPORTANT: Your agent must request logprobs=True in API calls for harmony
-# token parsing to work. Without logprobs, only text-based fallback is used.
-harmony:
-  enabled: auto                 # Enable harmony processing
-                                # auto (default) = Auto-detect harmony agents
-                                # yes/true/force/on = Force enable for all agents
-                                # no/false/off = Disable harmony processing
-  show_detailed_thinking: true  # Show reasoning/analysis/commentary with prefixes
-                                # When true (default), displays internal reasoning,
-                                # analysis, and commentary channels with labeled
-                                # prefixes. When false, only shows final response
-
 # ============================================================================
 # PER-AGENT OVERRIDES
 # ============================================================================
